@@ -656,26 +656,47 @@ dynpred <- function(model,newdata,event=1,landmark,horizon,var.time,
                     ## calcul des proba a posteriori pour tous les temps s   
                     ppi <- rep(0,ns*nbland*ng)
                     
-                    out <- .Fortran("postprob2_comp",as.double(Y),as.double(X),
-                                    as.integer(ns),as.integer(nmes),as.integer(nobs),
-                                    as.integer(ng),as.integer(nv),as.integer(idiag),
-                                    as.integer(nwg),as.integer(ncor),
+                    out <- .Fortran(C_postprob2,
+                                    as.double(Y),
+                                    as.double(X),
+                                    as.integer(ns),
+                                    as.integer(nmes),
+                                    as.integer(nobs),
+                                    as.integer(ng),
+                                    as.integer(nv),
+                                    as.integer(idiag),
+                                    as.integer(nwg),
+                                    as.integer(ncor),
                                     as.integer(logspecif),
-                                    as.double(zi),as.integer(idea),as.integer(idg),
-                                    as.integer(idprob),as.integer(idcor),
-                                    as.integer(idcom),as.integer(idspecif2),
-                                    as.integer(idtdv),as.integer(risqcom),
-                                    as.integer(nvdepsurv),as.integer(typrisq),
-                                    as.integer(nz),as.integer(nprisq),
-                                    as.integer(nbzitr),as.double(zitr),
-                                    as.integer(idlink),as.integer(indiceY),
-                                    as.double(uniqueY),as.integer(nvalSPL),
-                                    as.double(epsY),as.integer(nbevt),
-                                    as.double(tsurv0),as.integer(idtrunc),
-                                    as.double(best),as.integer(npm),
-                                    as.double(timemes),as.double(landmark),
-                                    as.integer(nbland),ppi=as.double(ppi),
-                                    PACKAGE="lcmm")
+                                    as.double(zi),
+                                    as.integer(idea),
+                                    as.integer(idg),
+                                    as.integer(idprob),
+                                    as.integer(idcor),
+                                    as.integer(idcom),
+                                    as.integer(idspecif2),
+                                    as.integer(idtdv),
+                                    as.integer(risqcom),
+                                    as.integer(nvdepsurv),
+                                    as.integer(typrisq),
+                                    as.integer(nz),
+                                    as.integer(nprisq),
+                                    as.integer(nbzitr),
+                                    as.double(zitr),
+                                    as.integer(idlink),
+                                    as.integer(indiceY),
+                                    as.double(uniqueY),
+                                    as.integer(nvalSPL),
+                                    as.double(epsY),
+                                    as.integer(nbevt),
+                                    as.double(tsurv0),
+                                    as.integer(idtrunc),
+                                    as.double(best),
+                                    as.integer(npm),
+                                    as.double(timemes),
+                                    as.double(landmark),
+                                    as.integer(nbland),
+                                    ppi=as.double(ppi))
                     
                     out$ppi[which(out$ppi==-5)] <- NA
                     ppi <- matrix(out$ppi,ns*nbland,ng)
@@ -950,26 +971,47 @@ dynpred <- function(model,newdata,event=1,landmark,horizon,var.time,
                             ## calcul des proba a posteriori pour tous les temps s   
                             ppi <- rep(0,ns*nbland*ng)
                             
-                            out <- .Fortran("postprob2_comp",as.double(Y),as.double(X),
-                                            as.integer(ns),as.integer(nmes),as.integer(nobs),
-                                            as.integer(ng),as.integer(nv),as.integer(idiag),
-                                            as.integer(nwg),as.integer(ncor),
-                                            as.integer(logspecif),as.double(zi),
-                                            as.integer(idea),as.integer(idg),
-                                            as.integer(idprob),as.integer(idcor),
-                                            as.integer(idcom),as.integer(idspecif2),
-                                            as.integer(idtdv),as.integer(risqcom),
-                                            as.integer(nvdepsurv),as.integer(typrisq),
-                                            as.integer(nz),as.integer(nprisq),
-                                            as.integer(nbzitr),as.double(zitr),
-                                            as.integer(idlink),as.integer(indiceY),
-                                            as.double(uniqueY),as.integer(nvalSPL),
-                                            as.double(epsY),as.integer(nbevt),
-                                            as.double(tsurv0),as.integer(idtrunc),
-                                            as.double(bdraw),as.integer(npm),
-                                            as.double(timemes),as.double(landmark),
-                                            as.integer(nbland),ppi=as.double(ppi),
-                                            PACKAGE="lcmm") 
+                            out <- .Fortran(C_postprob2,
+                                            as.double(Y),
+                                            as.double(X),
+                                            as.integer(ns),
+                                            as.integer(nmes),
+                                            as.integer(nobs),
+                                            as.integer(ng),
+                                            as.integer(nv),
+                                            as.integer(idiag),
+                                            as.integer(nwg),
+                                            as.integer(ncor),
+                                            as.integer(logspecif),
+                                            as.double(zi),
+                                            as.integer(idea),
+                                            as.integer(idg),
+                                            as.integer(idprob),
+                                            as.integer(idcor),
+                                            as.integer(idcom),
+                                            as.integer(idspecif2),
+                                            as.integer(idtdv),
+                                            as.integer(risqcom),
+                                            as.integer(nvdepsurv),
+                                            as.integer(typrisq),
+                                            as.integer(nz),
+                                            as.integer(nprisq),
+                                            as.integer(nbzitr),
+                                            as.double(zitr),
+                                            as.integer(idlink),
+                                            as.integer(indiceY),
+                                            as.double(uniqueY),
+                                            as.integer(nvalSPL),
+                                            as.double(epsY),
+                                            as.integer(nbevt),
+                                            as.double(tsurv0),
+                                            as.integer(idtrunc),
+                                            as.double(bdraw),
+                                            as.integer(npm),
+                                            as.double(timemes),
+                                            as.double(landmark),
+                                            as.integer(nbland),
+                                            ppi=as.double(ppi)) 
                             
                             out$ppi[which(out$ppi==-5)] <- NA
                             if(all(is.na(out$ppi))) return(rep(NA,ns*nbland*nbhoriz*nbevt))
