@@ -489,21 +489,48 @@ epoce <- function(model,pred.times,var.time,fun.time=identity,newdata=NULL,subse
     cat("Be patient, epoce function is running ... \n")
 
 
-    out <- .Fortran("cvpl",as.double(Y0),as.double(X0),as.integer(prior0),
-                    as.integer(idprob0),as.integer(idea0),as.integer(idg0),
-                    as.integer(idcor0),as.integer(idcom),as.integer(idspecif),
-                    as.integer(idtdv),as.integer(ns0),as.integer(ng0),
-                    as.integer(ncor0),as.integer(nv0),as.integer(nobs0),
-                    as.integer(nmes0),as.integer(idiag0),as.integer(nwg0),
-                    as.integer(NPM),as.double(Time),as.integer(typrisq0),
-                    as.integer(idtrunc),as.integer(risqcom0),as.integer(nz0),
-                    as.double(zi0),as.double(tsurv0),as.double(tsurv),
-                    as.integer(devt),as.integer(ind_survint),as.double(vopt),
-                    as.integer(nT),as.double(pred.times),best=as.double(best),
-                    epoir=as.double(epoir),rl_cond=as.double(rl_cond),
-                    ns_vect=as.integer(ns_vect),nevt_vect=as.integer(nevt_vect),
-                    contribt=as.double(contribt),as.integer(logspecif),
-                    as.integer(fix0),as.integer(npmssfix),PACKAGE="lcmm")
+    out <- .Fortran(C_cvpl,
+                    as.double(Y0),
+                    as.double(X0),
+                    as.integer(prior0),
+                    as.integer(idprob0),
+                    as.integer(idea0),
+                    as.integer(idg0),
+                    as.integer(idcor0),
+                    as.integer(idcom),
+                    as.integer(idspecif),
+                    as.integer(idtdv),
+                    as.integer(ns0),
+                    as.integer(ng0),
+                    as.integer(ncor0),
+                    as.integer(nv0),
+                    as.integer(nobs0),
+                    as.integer(nmes0),
+                    as.integer(idiag0),
+                    as.integer(nwg0),
+                    as.integer(NPM),
+                    as.double(Time),
+                    as.integer(typrisq0),
+                    as.integer(idtrunc),
+                    as.integer(risqcom0),
+                    as.integer(nz0),
+                    as.double(zi0),
+                    as.double(tsurv0),
+                    as.double(tsurv),
+                    as.integer(devt),
+                    as.integer(ind_survint),
+                    as.double(vopt),
+                    as.integer(nT),
+                    as.double(pred.times),
+                    best=as.double(best),
+                    epoir=as.double(epoir),
+                    rl_cond=as.double(rl_cond),
+                    ns_vect=as.integer(ns_vect),
+                    nevt_vect=as.integer(nevt_vect),
+                    contribt=as.double(contribt),
+                    as.integer(logspecif),
+                    as.integer(fix0),
+                    as.integer(npmssfix))
 
 
     ## construction de la matrice contribt
